Learn R Programming

gravmagsubs (version 1.0.1)

gravmagsubs-package: Gravitational and magnetic attraction of 3-D vertical rectangular prisms

Description

The package gravmagsubs provides tools for computing the gravitational and magnetic anomalies generated by 3-D vertical rectangular prisms at specific observation points. The package consists of two functions:

  • rectprismgrav : Computes the gravitational attraction of 3-D right rectangular prisms.

  • rectprismmag : Computes the magnetic effect of 3-D right rectangular prisms.

Each function can compute the total anomaly of a series of N prisms at M observation points.

Each function also has a logical flag bycell (default FALSE). If bycell=TRUE, the function returns the contribution from each individual prism.

Arguments

References

  • Plouff, D., 1976, Gravity and magnetic fields of polygonal prisms and application to magnetic terrain corrections, Geophysics, v. 41, pp. 727--741, tools:::Rd_expr_doi("10.1190/1.1440645").