# \donttest{
#########################################################
## gravity anomaly of a single prism at a single point ##
# location of the point where the gravity anomaly will be calculated
gravstation <- data.frame(x=0, y=0, z=0)
# the rectangular prism is defined by its six edges
prism1 <- data.frame(xmin=-5, xmax=5,
ymin=-5, ymax=5,
zmin=-10, zmax=-5)
# density contrast in g/cc
drho <- 0.3
gravanom <- rectprismgrav(gravstation$x, gravstation$y, gravstation$z,
prism1$xmin, prism1$xmax,
prism1$ymin, prism1$ymax,
prism1$zmin, prism1$zmax, drho)
#########################################################
# }
Run the code above in your browser using DataLab