# \donttest{
#########################################################
## magnetic anomaly of single prism at a single point ##
# location of the point where the magnetic anomaly will be calculated
magstation <- data.frame(x=0, y=0, z=0)
# the rectangular prism is defined by its six edges
prism1 <- data.frame(xmin=-5, xmax=5,
ymin=-5, ymax=5,
zmin=-10, zmax=-5)
susc <- 5 # susceptiblity (SI)
mstr <- 0 # remanent magnetization (A/m)
mincl <- 0 # remanent inclination (deg)
mdecl <- 0 # remanent declination (deg)
ftotal <- 48800 # Earth's field intensity (nT)
fincl <- 60 # field inclination (deg)
fdecl <- 12 # field declination (deg)
maganom <- rectprismmag(magstation$x, magstation$y, magstation$z,
prism1$xmin, prism1$xmax,
prism1$ymin, prism1$ymax,
prism1$zmin, prism1$zmax, susc,
mstr, mincl, mdecl,
ftotal, fincl, fdecl)
#########################################################
# }
Run the code above in your browser using DataLab